from typing import Any

from django.template import Library

from crimsonslate_portfolio.models import Media

register = Library()


@register.inclusion_tag("portfolio/media/display.html")
def media_display(
    media: Media,
    css_class: str | None = None,
    force_image: bool = False,
) -> dict[str, Any]:
    src = media.thumb.url if force_image and not media.is_image else media.source.url
    return {
        "title": media.title,
        "class": css_class,
        "image": force_image if force_image else media.is_image,
        "src": src,
        "link": media.get_absolute_url(),
    }



from django.views.generic import CreateView, UpdateView, DeleteView

from crimsonslate_portfolio.models import MediaTag
from crimsonslate_portfolio.views.mixins import HtmxTemplateResponseMixin


class TagCreateView(HtmxTemplateResponseMixin, CreateView):
    template_name = "crimsonslate_portfolio/tags/create.html"
    partial_template_name = "crimsonslate_portfolio/tags/partials/_create.html"
    model = MediaTag
    extra_context = {"class": "flex flex-col gap-4 p-4 border rounded bg-gray-200"}


class TagUpdateView(HtmxTemplateResponseMixin, UpdateView):
    template_name = "crimsonslate_portfolio/tags/update.html"
    partial_template_name = "crimsonslate_portfolio/tags/partials/_update.html"
    model = MediaTag
    extra_context = {"class": "flex flex-col gap-4 p-4 border rounded bg-gray-200"}


class TagDeleteView(HtmxTemplateResponseMixin, DeleteView):
    template_name = "crimsonslate_portfolio/tags/delete.html"
    partial_template_name = "crimsonslate_portfolio/tags/partials/_delete.html"
    model = MediaTag
    extra_context = {"class": "flex flex-col gap-4 p-4 border rounded bg-gray-200"}



from .generic import ContactView, LoginView, LogoutView
from .media import (
    MediaCreateView,
    MediaDeleteView,
    MediaDetailView,
    MediaGalleryView,
    MediaSearchView,
    MediaUpdateView,
    MediaUploadView,
    MediaUploadSuccessView,
    MediaSearchResultsView,
)
from .tags import (
    TagCreateView,
    TagDeleteView,
    TagUpdateView,
)
